## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)
# .libPaths(.Library)

## ----load libraries-----------------------------------------------------------
library(anglemania)
library(SingleCellExperiment)

## -----------------------------------------------------------------------------
sce <- sce_example()
batch_key <- "batch"
angl <- create_anglemania_object(sce, batch_key = batch_key)
angl <- anglemania(angl)
angl

## -----------------------------------------------------------------------------
barcodes_by_batch <- split(rownames(colData(sce)), colData(sce)[[batch_key]])
counts_by_batch <- lapply(barcodes_by_batch, function(x) {
    counts(sce[, x]) %>% sparse_to_fbm()
})
counts_by_batch[[1]][1:10, 1:6]
class(counts_by_batch[[1]])
factorised <- lapply(counts_by_batch, factorise)
factorised[[1]][1:10, 1:6]

## -----------------------------------------------------------------------------
sce <- sce_example()
batch_key <- "batch"
angl <- create_anglemania_object(sce, batch_key = batch_key)
list_stats(angl) # this slot is empty
angl <- anglemania(angl) 
names(list_stats(angl))
class(list_stats(angl))
list_stats(angl)$mean_zscore[1:10, 1:6]
list_stats(angl)$sn_zscore[1:10, 1:6]

## -----------------------------------------------------------------------------
previous_genes <- get_anglemania_genes(angl)
angl <- select_genes(angl,
                     zscore_mean_threshold = 2,
                     zscore_sn_threshold = 2)
# Inspect the anglemania genes
new_genes <- get_anglemania_genes(angl)

length(previous_genes)
length(new_genes)

